@@ -18,11 +18,7 @@ from pyproj.crs.coordinate_operation import (
     VerticalPerspectiveConversion,
 )
 from pyproj.exceptions import CRSError
-from test.conftest import (
-    HAYFORD_ELLIPSOID_NAME,
-    PROJ_LOOSE_VERSION,
-    get_wgs84_datum_name,
-)
+from test.conftest import PROJ_GTE_901, PROJ_LOOSE_VERSION
 
 
 def _to_dict(operation):
@@ -85,16 +81,22 @@ def test_to_cf_transverse_mercator():
         towgs84="-122.74,-34.27,-22.83,-1.884,-3.400,-3.030,-15.62",
     )
     towgs84_test = [-122.74, -34.27, -22.83, -1.884, -3.4, -3.03, -15.62]
+    horizontal_datum_name = (
+        "Unknown based on International 1924 (Hayford 1909, 1910) ellipsoid"
+    )
+    if PROJ_GTE_901:
+        horizontal_datum_name = (
+            f"{horizontal_datum_name} using "
+            "towgs84=-122.74,-34.27,-22.83,-1.884,-3.400,-3.030,-15.62"
+        )
     expected_cf = {
         "semi_major_axis": 6378388.0,
         "semi_minor_axis": crs.ellipsoid.semi_minor_metre,
         "inverse_flattening": 297.0,
-        "reference_ellipsoid_name": HAYFORD_ELLIPSOID_NAME,
+        "reference_ellipsoid_name": "International 1924 (Hayford 1909, 1910)",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": (
-            f"Unknown based on {HAYFORD_ELLIPSOID_NAME} ellipsoid"
-        ),
+        "horizontal_datum_name": horizontal_datum_name,
         "towgs84": towgs84_test,
         "grid_mapping_name": "transverse_mercator",
         "latitude_of_projection_origin": 0.0,
@@ -165,7 +167,7 @@ def test_from_cf_transverse_mercator(towgs84_test):
         "semi_major_axis": 6378388.0,
         "semi_minor_axis": crs.ellipsoid.semi_minor_metre,
         "inverse_flattening": 297.0,
-        "reference_ellipsoid_name": HAYFORD_ELLIPSOID_NAME,
+        "reference_ellipsoid_name": "International 1924 (Hayford 1909, 1910)",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
         "grid_mapping_name": "transverse_mercator",
@@ -271,7 +273,7 @@ def test_cf_from_utm():
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
         "geographic_crs_name": "WGS 84",
-        "horizontal_datum_name": get_wgs84_datum_name(),
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "projected_crs_name": "WGS 84 / UTM zone 15N",
         "grid_mapping_name": "transverse_mercator",
         "latitude_of_projection_origin": 0.0,
@@ -391,8 +393,8 @@ def test_cf_rotated_latlon():
         "proj": "ob_tran",
         "o_proj": "longlat",
         "o_lat_p": 32.5,
-        "o_lon_p": 170.0,
-        "lon_0": 0,
+        "o_lon_p": 0,
+        "lon_0": 350,
         "datum": "WGS84",
         "no_defs": None,
         "type": "crs",
@@ -404,8 +406,8 @@ def test_cf_rotated_latlon__grid():
         dict(
             grid_mapping_name="rotated_latitude_longitude",
             grid_north_pole_latitude=32.5,
-            grid_north_pole_longitude=170.0,
-            north_pole_grid_longitude=1.0,
+            grid_north_pole_longitude=1.0,
+            north_pole_grid_longitude=170.0,
         )
     )
     with pytest.warns(UserWarning):
@@ -415,13 +417,68 @@ def test_cf_rotated_latlon__grid():
         "o_proj": "longlat",
         "o_lat_p": 32.5,
         "o_lon_p": 170.0,
-        "lon_0": 1.0,
+        "lon_0": 181.0,
         "datum": "WGS84",
         "no_defs": None,
         "type": "crs",
     }
 
 
+def test_rotated_pole_to_cf():
+    rotated_pole_wkt = (
+        'GEOGCRS["undefined",\n'
+        '    BASEGEOGCRS["Unknown datum based upon the GRS 1980 ellipsoid",\n'
+        '        DATUM["Not specified (based on GRS 1980 ellipsoid)",\n'
+        '            ELLIPSOID["GRS 1980",6378137,298.257222101,\n'
+        '                LENGTHUNIT["metre",1]]],\n'
+        '        PRIMEM["Greenwich",0,\n'
+        '            ANGLEUNIT["degree",0.0174532925199433]]],\n'
+        '    DERIVINGCONVERSION["Pole rotation (netCDF CF convention)",\n'
+        '        METHOD["Pole rotation (netCDF CF convention)"],\n'
+        '        PARAMETER["Grid north pole latitude (netCDF CF '
+        'convention)",2,\n'
+        '            ANGLEUNIT["degree",0.0174532925199433,\n'
+        '                ID["EPSG",9122]]],\n'
+        '        PARAMETER["Grid north pole longitude (netCDF CF '
+        'convention)",3,\n'
+        '            ANGLEUNIT["degree",0.0174532925199433,\n'
+        '                ID["EPSG",9122]]],\n'
+        '        PARAMETER["North pole grid longitude (netCDF CF '
+        'convention)",4,\n'
+        '            ANGLEUNIT["degree",0.0174532925199433,\n'
+        '                ID["EPSG",9122]]]],\n'
+        "    CS[ellipsoidal,2],\n"
+        '        AXIS["geodetic latitude (Lat)",north,\n'
+        "            ORDER[1],\n"
+        '            ANGLEUNIT["degree",0.0174532925199433,\n'
+        '                ID["EPSG",9122]]],\n'
+        '        AXIS["geodetic longitude (Lon)",east,\n'
+        "            ORDER[2],\n"
+        '            ANGLEUNIT["degree",0.0174532925199433,\n'
+        '                ID["EPSG",9122]]]]'
+    )
+    crs = CRS(rotated_pole_wkt)
+    expected_cf = {
+        "semi_major_axis": 6378137.0,
+        "semi_minor_axis": 6356752.314140356,
+        "inverse_flattening": 298.257222101,
+        "reference_ellipsoid_name": "GRS 1980",
+        "longitude_of_prime_meridian": 0.0,
+        "prime_meridian_name": "Greenwich",
+        "geographic_crs_name": "undefined",
+        "grid_mapping_name": "rotated_latitude_longitude",
+        "grid_north_pole_latitude": 2.0,
+        "grid_north_pole_longitude": 3.0,
+        "north_pole_grid_longitude": 4.0,
+        "horizontal_datum_name": "Not specified (based on GRS 1980 ellipsoid)",
+    }
+    cf_dict = crs.to_cf()
+    assert cf_dict.pop("crs_wkt").startswith("GEOGCRS[")
+    assert cf_dict == expected_cf
+    # test roundtrip
+    _test_roundtrip(expected_cf, "GEOGCRS[")
+
+
 def test_cf_lambert_conformal_conic_1sp():
     crs = CRS.from_cf(
         dict(
@@ -1555,7 +1612,6 @@ def test_build_custom_datum__default_ellipsoid():
 def test_cartesian_cs():
     unit = {"type": "LinearUnit", "name": "US Survey Foot", "conversion_factor": 0.3048}
     cartesian_cs = {
-        "$schema": "https://proj.org/schemas/v0.2/projjson.schema.json",
         "type": "CoordinateSystem",
         "subtype": "Cartesian",
         "axis": [
@@ -1582,7 +1638,9 @@ def test_cartesian_cs():
         },
         cartesian_cs=cartesian_cs,
     )
-    assert crs.coordinate_system.to_json_dict() == cartesian_cs
+    json_dict = crs.coordinate_system.to_json_dict()
+    json_dict.pop("$schema")
+    assert json_dict == cartesian_cs
     # test coordinate system
     assert crs.cs_to_cf() == [
         {
@@ -1602,7 +1660,6 @@ def test_cartesian_cs():
 
 def test_ellipsoidal_cs():
     ellipsoidal_cs = {
-        "$schema": "https://proj.org/schemas/v0.2/projjson.schema.json",
         "type": "CoordinateSystem",
         "subtype": "ellipsoidal",
         "axis": [
@@ -1628,7 +1685,9 @@ def test_ellipsoidal_cs():
         ),
         ellipsoidal_cs=ellipsoidal_cs,
     )
-    assert crs.coordinate_system.to_json_dict() == ellipsoidal_cs
+    json_dict = crs.coordinate_system.to_json_dict()
+    json_dict.pop("$schema")
+    assert json_dict == ellipsoidal_cs
     # test coordinate system
     assert crs.cs_to_cf() == [
         {
@@ -1648,7 +1707,6 @@ def test_ellipsoidal_cs():
 
 def test_ellipsoidal_cs__from_name():
     ellipsoidal_cs = {
-        "$schema": "https://proj.org/schemas/v0.2/projjson.schema.json",
         "type": "CoordinateSystem",
         "subtype": "ellipsoidal",
         "axis": [
@@ -1670,7 +1728,9 @@ def test_ellipsoidal_cs__from_name():
         dict(grid_mapping_name="latitude_longitude", geographic_crs_name="WGS 84"),
         ellipsoidal_cs=ellipsoidal_cs,
     )
-    assert crs.coordinate_system.to_json_dict() == ellipsoidal_cs
+    json_dict = crs.coordinate_system.to_json_dict()
+    json_dict.pop("$schema")
+    assert json_dict == ellipsoidal_cs
     # test coordinate system
     assert crs.cs_to_cf() == [
         {
@@ -1691,7 +1751,6 @@ def test_ellipsoidal_cs__from_name():
 def test_export_compound_crs_cs():
     unit = {"type": "LinearUnit", "name": "US Survey Foot", "conversion_factor": 0.3048}
     cartesian_cs = {
-        "$schema": "https://proj.org/schemas/v0.2/projjson.schema.json",
         "type": "CoordinateSystem",
         "subtype": "Cartesian",
         "axis": [
@@ -1705,7 +1764,6 @@ def test_export_compound_crs_cs():
         ],
     }
     vertical_cs = {
-        "$schema": "https://proj.org/schemas/v0.2/projjson.schema.json",
         "type": "CoordinateSystem",
         "subtype": "vertical",
         "axis": [
@@ -1740,8 +1798,12 @@ def test_export_compound_crs_cs():
         cartesian_cs=cartesian_cs,
         vertical_cs=vertical_cs,
     )
-    assert crs.sub_crs_list[0].coordinate_system.to_json_dict() == cartesian_cs
-    assert crs.sub_crs_list[1].coordinate_system.to_json_dict() == vertical_cs
+    cartesian_json_dict = crs.sub_crs_list[0].coordinate_system.to_json_dict()
+    cartesian_json_dict.pop("$schema")
+    vertical_json_dict = crs.sub_crs_list[1].coordinate_system.to_json_dict()
+    vertical_json_dict.pop("$schema")
+    assert cartesian_json_dict == cartesian_cs
+    assert vertical_json_dict == vertical_cs
     # test coordinate system
     assert crs.cs_to_cf() == [
         {
