@@ -1,5 +1,6 @@
 import concurrent.futures
 import os
+import pickle
 from array import array
 from functools import partial
 from glob import glob
@@ -18,8 +19,8 @@ from pyproj.enums import TransformDirection
 from pyproj.exceptions import ProjError
 from pyproj.transformer import AreaOfInterest, TransformerGroup
 from test.conftest import (
-    PROJ_GTE_8,
     PROJ_GTE_81,
+    RGF93toWSG84,
     grids_available,
     proj_env,
     proj_network_env,
@@ -52,7 +53,7 @@ def test_transform_wgs84_to_alaska():
         assert f"{xx:.3f} {yy:.3f}" == "-1825155.697 330730.391"
 
 
-@pytest.mark.skipif(PROJ_GTE_8, reason="https://github.com/OSGeo/PROJ/issues/2425")
+@pytest.mark.skip(reason="https://github.com/OSGeo/PROJ/issues/2425")
 def test_illegal_transformation():
     # issue 202
     with pytest.warns(FutureWarning):
@@ -458,12 +459,10 @@ def test_str():
 
 if PROJ_GTE_81:
     _BOUND_REPR = "(-16.1, 32.88, 40.18, 84.73)"
-elif PROJ_GTE_8:
+else:
     _BOUND_REPR = (
         "(-16.096100515106, 32.884955146013, 40.178745269776, 84.722623821813)"
     )
-else:
-    _BOUND_REPR = "(-16.1, 32.88, 40.18, 84.17)"
 
 
 @pytest.mark.parametrize(
@@ -1119,19 +1118,11 @@ def test_transformer_multithread__crs():
             pass
 
 
-@pytest.mark.skipif(not PROJ_GTE_8, reason="Requires PROJ 8+")
 def test_transformer_accuracy_filter():
     with pytest.raises(ProjError):
         Transformer.from_crs("EPSG:4326", "EPSG:4258", accuracy=0.05)
 
 
-@pytest.mark.skipif(PROJ_GTE_8, reason="Warning for PROJ<8")
-def test_transformer_accuracy_filter_warning():
-    with pytest.warns(UserWarning, match="accuracy requires PROJ 8+"):
-        Transformer.from_crs("EPSG:4326", "EPSG:4258", accuracy=0.05)
-
-
-@pytest.mark.skipif(not PROJ_GTE_8, reason="Requires PROJ 8+")
 def test_transformer_allow_ballpark_filter():
     with pytest.raises(ProjError):
         Transformer.from_crs(
@@ -1139,34 +1130,21 @@ def test_transformer_allow_ballpark_filter():
         )
 
 
-@pytest.mark.skipif(PROJ_GTE_8, reason="Warning for PROJ<8")
-def test_transformer_allow_ballpark_filter_warning():
-    with pytest.warns(UserWarning, match="allow_ballpark requires PROJ 8+"):
-        Transformer.from_crs("EPSG:4326", "EPSG:4258", allow_ballpark=False)
-
-
-@pytest.mark.skipif(not PROJ_GTE_8, reason="Requires PROJ 8+")
 def test_transformer_authority_filter():
     transformer = Transformer.from_crs("EPSG:4326", "EPSG:4258", authority="PROJ")
     assert transformer.description == "Ballpark geographic offset from WGS 84 to ETRS89"
 
 
-@pytest.mark.skipif(PROJ_GTE_8, reason="Warning for PROJ<8")
-def test_transformer_authority_filter_warning():
-    with pytest.warns(UserWarning, match="authority requires PROJ 8+"):
-        Transformer.from_crs("EPSG:4326", "EPSG:4258", authority="PROJ")
-
-
 @pytest.mark.parametrize(
     "input_string",
     [
         "EPSG:1671",
-        "RGF93 to WGS 84 (1)",
+        RGF93toWSG84,
         "urn:ogc:def:coordinateOperation:EPSG::1671",
     ],
 )
 def test_transformer_from_pipeline__input_types(input_string):
-    assert Transformer.from_pipeline(input_string).description == "RGF93 to WGS 84 (1)"
+    assert Transformer.from_pipeline(input_string).description == RGF93toWSG84
 
 
 @pytest.mark.parametrize(
@@ -1184,7 +1162,7 @@ def test_transformer_from_pipeline__wkt_json(method_name):
                 method_name,
             )()
         ).description
-        == "RGF93 to WGS 84 (1)"
+        == RGF93toWSG84
     )
 
 
@@ -1344,6 +1322,26 @@ def test_transform_bounds__ignore_inf(input_crs, expected_bounds):
     )
 
 
+def test_transform_bounds__ignore_inf_geographic():
+    crs_wkt = (
+        'PROJCS["Interrupted_Goode_Homolosine",'
+        'GEOGCS["GCS_unnamed ellipse",DATUM["D_unknown",'
+        'SPHEROID["Unknown",6378137,298.257223563]],'
+        'PRIMEM["Greenwich",0],UNIT["Degree",0.0174532925199433]],'
+        'PROJECTION["Interrupted_Goode_Homolosine"],'
+        'UNIT["metre",1,AUTHORITY["EPSG","9001"]],'
+        'AXIS["Easting",EAST],AXIS["Northing",NORTH]]'
+    )
+    transformer = Transformer.from_crs(crs_wkt, "EPSG:4326", always_xy=True)
+    assert_almost_equal(
+        transformer.transform_bounds(
+            left=-15028000.0, bottom=7515000.0, right=-14975000.0, top=7556000.0
+        ),
+        (-179.2133, 70.9345, -177.9054, 71.4364),
+        decimal=0,
+    )
+
+
 def test_transform_bounds__noop_geographic():
     crs = CRS("Pulkovo 1942")
     transformer = Transformer.from_crs(crs.geodetic_crs, crs, always_xy=True)
@@ -1353,6 +1351,82 @@ def test_transform_bounds__noop_geographic():
     )
 
 
+def test_transform_bounds__north_pole():
+    crs = CRS("EPSG:32661")
+    transformer = Transformer.from_crs(crs, "EPSG:4326")
+    minx, miny, maxx, maxy = crs.area_of_use.bounds
+    bounds = transformer.transform_bounds(miny, minx, maxy, maxx, direction="INVERSE")
+    assert_almost_equal(
+        bounds,
+        (
+            -1405880.72,
+            -1371213.76,
+            5405880.72,
+            5371213.76,
+        ),
+        decimal=0,
+    )
+    assert_almost_equal(
+        transformer.transform_bounds(*bounds),
+        (48.656, -180.0, 90.0, 180.0),
+        decimal=0,
+    )
+
+
+def test_transform_bounds__north_pole__xy():
+    crs = CRS("EPSG:32661")
+    transformer = Transformer.from_crs(crs, "EPSG:4326", always_xy=True)
+    bounds = transformer.transform_bounds(*crs.area_of_use.bounds, direction="INVERSE")
+    assert_almost_equal(
+        bounds,
+        (-1371213.76, -1405880.72, 5371213.76, 5405880.72),
+        decimal=0,
+    )
+    assert_almost_equal(
+        transformer.transform_bounds(*bounds),
+        (-180.0, 48.656, 180.0, 90.0),
+        decimal=0,
+    )
+
+
+def test_transform_bounds__south_pole():
+    crs = CRS("EPSG:32761")
+    transformer = Transformer.from_crs(crs, "EPSG:4326")
+    minx, miny, maxx, maxy = crs.area_of_use.bounds
+    bounds = transformer.transform_bounds(miny, minx, maxy, maxx, direction="INVERSE")
+    assert_almost_equal(
+        bounds,
+        (
+            -1405880.72,
+            -1371213.76,
+            5405880.72,
+            5371213.76,
+        ),
+        decimal=0,
+    )
+    assert_almost_equal(
+        transformer.transform_bounds(*bounds),
+        (-90, -180.0, -48.656, 180.0),
+        decimal=0,
+    )
+
+
+def test_transform_bounds__south_pole__xy():
+    crs = CRS("EPSG:32761")
+    transformer = Transformer.from_crs(crs, "EPSG:4326", always_xy=True)
+    bounds = transformer.transform_bounds(*crs.area_of_use.bounds, direction="INVERSE")
+    assert_almost_equal(
+        bounds,
+        (-1371213.76, -1405880.72, 5371213.76, 5405880.72),
+        decimal=0,
+    )
+    assert_almost_equal(
+        transformer.transform_bounds(*bounds),
+        (-180.0, -90.0, 180.0, -48.656),
+        decimal=0,
+    )
+
+
 @pytest.mark.parametrize("inplace", [True, False])
 def test_transform__fortran_order(inplace):
     lons, lats = np.arange(-180, 180, 20), np.arange(-90, 90, 10)
@@ -1449,3 +1523,30 @@ def test_4d_transform__inplace__numpy__int():
     assert zarr[0] == 5264462
     assert tarr is not t_tarr
     assert tarr[0] == 2019
+
+
+def test_transformer_source_target_crs():
+    transformer = Transformer.from_crs("EPSG:4326", "EPSG:4258")
+    assert transformer.source_crs == "EPSG:4326"
+    assert transformer.target_crs == "EPSG:4258"
+
+
+def test_transformer_source_target_crs__none():
+    transformer = Transformer.from_pipeline("+init=ITRF2008:ITRF2000")
+    assert transformer.source_crs is None
+    assert transformer.target_crs is None
+
+
+def test_pickle_transformer_from_pipeline():
+    transformer = Transformer.from_pipeline("+init=ITRF2008:ITRF2000")
+    assert transformer == pickle.loads(pickle.dumps(transformer))
+
+
+def test_pickle_transformer_from_crs():
+    transformer = Transformer.from_crs(
+        "EPSG:4326",
+        "EPSG:2964",
+        always_xy=True,
+        area_of_interest=AreaOfInterest(-136.46, 49.0, -60.72, 83.17),
+    )
+    assert transformer == pickle.loads(pickle.dumps(transformer))
